@@ -10,7 +10,6 @@ Thanks to Werner van Geit for an initial version of a python wrapper for jnml.
 """
 
 from __future__ import absolute_import
-from __future__ import print_function
 from __future__ import unicode_literals
 
 # py3.7, 3.8 require this to use standard collections as generics
@@ -34,8 +33,6 @@ import tempfile
 import typing
 import traceback
 
-import matplotlib
-import matplotlib.axes
 import lems.model.model as lems_model
 import lems
 from lems.parser.LEMS import LEMSFileParser
@@ -48,6 +45,10 @@ from neuroml import NeuroMLDocument, Cell
 import neuroml.loaders as loaders
 import neuroml.writers as writers
 
+# to maintain API compatibility:
+# so that existing scripts that use: from pynml import generate_plot
+# continue to work
+from pyneuroml.plot import generate_plot, generate_interactive_plot  # noqa
 
 DEFAULTS = {
     "v": False,
@@ -571,7 +572,7 @@ def convert_to_units(nml2_quantity: str, unit: str) -> float:
                     )
                 )
 
-    logger.info(
+    logger.debug(
         "Converting {} {} to {}: {} ({} in SI units)".format(
             m, u, unit, new_value, si_value
         )
@@ -1092,7 +1093,7 @@ def write_neuroml2_file(
     writers.NeuroMLWriter.write(nml2_doc, nml2_file_name)
 
     if validate:
-        validate_neuroml2(nml2_file_name, verbose_validate)
+        return validate_neuroml2(nml2_file_name, verbose_validate)
 
 
 def read_lems_file(
@@ -1655,20 +1656,24 @@ def run_lems_with_eden(
     :type verbose: bool
     """
 
-
     import eden_simulator
+
     logger.info(
         "Running a simulation of %s in EDEN v%s"
         % (
             lems_file_name,
-            eden_simulator.__version__ if hasattr(eden_simulator, "__version__") else "???",
+            eden_simulator.__version__
+            if hasattr(eden_simulator, "__version__")
+            else "???",
         )
     )
 
     results = eden_simulator.runEden(lems_file_name)
 
     if verbose:
-        logger.info("Completed simulation in EDEN, saved results: %s"%(results.keys()))
+        logger.info(
+            "Completed simulation in EDEN, saved results: %s" % (results.keys())
+        )
 
     if load_saved_data:
         logger.warning("Event saving is not yet supported in EDEN!!")
@@ -1679,7 +1684,6 @@ def run_lems_with_eden(
         return True
 
 
-
 def reload_saved_data(
     lems_file_name: str,
     base_dir: str = ".",
@@ -2444,7 +2448,7 @@ def execute_command_in_dir_with_realtime_output(
         )
         with p.stdout:
             for line in iter(p.stdout.readline, ""):
-                print("# %s"%line.strip())
+                print("# %s" % line.strip())
         p.wait()  # wait for the subprocess to exit
 
         print("####################################################################")
@@ -2540,216 +2544,6 @@ def execute_command_in_dir(
         return (-1, str(e))
 
 
-def generate_plot(
-    xvalues: list[float],
-    yvalues: list[float],
-    title: str,
-    labels: typing.Optional[list[str]] = None,
-    colors: typing.Optional[list[str]] = None,
-    linestyles: typing.Optional[list[str]] = None,
-    linewidths: typing.Optional[list[str]] = None,
-    markers: typing.Optional[list[str]] = None,
-    markersizes: typing.Optional[list[str]] = None,
-    xaxis: str = None,
-    yaxis: str = None,
-    xlim: str = None,
-    ylim: str = None,
-    show_xticklabels: bool = True,
-    show_yticklabels: bool = True,
-    grid: bool = False,
-    logx: bool = False,
-    logy: bool = False,
-    font_size: int = 12,
-    bottom_left_spines_only: bool = False,
-    cols_in_legend_box: int = 3,
-    legend_position: typing.Optional[str] = None,
-    show_plot_already: bool = True,
-    save_figure_to: typing.Optional[str] = None,
-    title_above_plot: bool = False,
-    verbose: bool = False,
-) -> matplotlib.axes.Axes:
-    """Utility function to generate plots using the Matplotlib library.
-
-    This function can be used to generate graphs with multiple plot lines.
-    For example, to plot two metrics you can use:
-
-    ::
-
-        generate_plot(xvalues=[[ax1, ax2, ax3], [bx1, bx2, bx3]], yvalues=[[ay1, ay2, ay3], [by1, by2, by3]], labels=["metric 1", "metric 2"])
-
-    Please note that while plotting multiple plots, you should take care to
-    ensure that the number of x values and y values for each metric correspond.
-    These lists are passed directly to Matplotlib for plotting without
-    additional sanity checks.
-
-    Please see the Matplotlib documentation for the complete list of available
-    styles and colours:
-    - https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.plot.html
-    - https://matplotlib.org/stable/gallery/index.html
-
-    :param xvalues: X values
-    :type xvalues: list of lists
-    :param yvalues: Y values
-    :type yvalues: lists of lists
-    :param title: title of plot
-    :type title: str
-    :param labels: labels for each plot (default: None)
-    :type labels: list of strings
-    :param colors: colours for each plot (default: None)
-    :type colors: list of strings
-    :param linestyles: list of line styles (default: None)
-    :type linestyles: list strings
-    :param linewidths: list of line widths (default: None)
-    :type linewidths: list of floats
-    :param markers: list of markers (default: None)
-    :type markers: list strings
-    :param markersizes: list of marker sizes (default: None)
-    :type markersizes: list of floats
-    :param xaxis: label of X axis (default: None)
-    :type xaxis: str
-    :param yaxis: label of Y axis (default: None)
-    :type yaxis: str
-    :param xlim: left and right extents of x axis (default: None)
-    :type xlim: tuple of (float, float) or individual arguments: (left=float), (right=float)
-                See https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.xlim.html
-    :param ylim: top and bottom extents of y axis (default: None)
-    :type ylim: tuple of (float, float) or individual arguments: (top=float), (bottom=float)
-                See https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.ylim.html
-    :param show_xticklabels: whether labels should be shown on xtics (default: True)
-    :type show_xticklabels: boolean
-    :param show_yticklabels: whether labels should be shown on ytics (default: True)
-    :type show_yticklabels: boolean
-    :param grid: enable/disable grid (default: False)
-    :type grid: boolean
-    :param logx: should the x axis be in log scale (default: False)
-    :type logx: boolean
-    :param logy: should the y ayis be in log scale (default: False)
-    :type logy: boolean
-    :param font_size: font size (default: 12)
-    :type font_size: float
-    :param bottom_left_spines_only: enable/disable spines on right and top (default: False)
-                (a spine is line noting the data area boundary)
-    :type bottom_left_spines_only: boolean
-    :param cols_in_legend_box: number of columns to use in legend box (default: 3)
-    :type cols_in_legend_box: float
-    :param legend_position: position of legend: (default: None)
-                See: https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.legend.html
-    :type legend_position: str
-    :param show_plot_already: if plot should be shown when created (default: True)
-    :type show_plot_already: boolean
-    :param save_figure_to: location to save generated figure to (default: None)
-    :type save_figure_to: str
-    :param title_above_plot: enable/disable title above the plot (default: False)
-    :type title_above_plot: boolean
-    :param verbose: enable/disable verbose logging (default: False)
-    :type verbose: boolean
-    :returns: matplotlib.axes.Axes object
-    """
-
-    logger.info("Generating plot: %s" % (title))
-
-    from matplotlib import pyplot as plt
-    from matplotlib import rcParams
-
-    rcParams.update({"font.size": font_size})
-
-    fig = plt.figure()
-    ax = fig.add_subplot(111)
-
-    plt.get_current_fig_manager().set_window_title(title)
-    if title_above_plot:
-        plt.title(title)
-
-    if xaxis:
-        plt.xlabel(xaxis)
-    if yaxis:
-        plt.ylabel(yaxis)
-
-    if grid:
-        plt.grid("on")
-
-    if logx:
-        ax.set_xscale("log")
-    if logy:
-        ax.set_yscale("log")
-
-    if bottom_left_spines_only:
-        ax.spines["right"].set_visible(False)
-        ax.spines["top"].set_visible(False)
-        ax.yaxis.set_ticks_position("left")
-        ax.xaxis.set_ticks_position("bottom")
-
-    if not show_xticklabels:
-        ax.set_xticklabels([])
-    if not show_yticklabels:
-        ax.set_yticklabels([])
-
-    for i in range(len(xvalues)):
-
-        linestyle = "-" if not linestyles else linestyles[i]
-        label = "" if not labels else labels[i]
-        marker = None if not markers else markers[i]
-        linewidth = 1 if not linewidths else linewidths[i]
-        markersize = 6 if not markersizes else markersizes[i]
-
-        if colors:
-            plt.plot(
-                xvalues[i],
-                yvalues[i],
-                "o",
-                color=colors[i],
-                marker=marker,
-                markersize=markersize,
-                linestyle=linestyle,
-                linewidth=linewidth,
-                label=label,
-            )
-        else:
-            plt.plot(
-                xvalues[i],
-                yvalues[i],
-                "o",
-                marker=marker,
-                markersize=markersize,
-                linestyle=linestyle,
-                linewidth=linewidth,
-                label=label,
-            )
-
-    if labels:
-        if legend_position == "right":
-            box = ax.get_position()
-            ax.set_position([box.x0, box.y0, box.width * 0.8, box.height])
-            # Put a legend to the right of the current axis
-            ax.legend(loc="center left", bbox_to_anchor=(1, 0.5))
-
-        else:
-            plt.legend(
-                loc="upper center",
-                bbox_to_anchor=(0.5, -0.05),
-                fancybox=True,
-                shadow=True,
-                ncol=cols_in_legend_box,
-            )
-
-    if xlim:
-        plt.xlim(xlim)
-    if ylim:
-        plt.ylim(ylim)
-
-    if save_figure_to:
-        logger.info(
-            "Saving image to %s of plot: %s" % (os.path.abspath(save_figure_to), title)
-        )
-        plt.savefig(save_figure_to, bbox_inches="tight")
-        logger.info("Saved image to %s of plot: %s" % (save_figure_to, title))
-
-    if show_plot_already:
-        plt.show()
-
-    return ax
-
-
 """
     As usually saved by jLEMS, etc. First column is time (in seconds), multiple other columns
 """
